@@ -5,23 +5,26 @@
 #' Admin Panel.  If your app is set up with the default 'polished' configuration, this button appears
 #' in the bottom right of your 'shiny' app.
 #'
-#' @param id the Shiny module id.
+#' @param align The horizontal alignment of the button. Valid options are "right" (the default)
+#' or "left".
+#' @param vertical_align the vertical alignment of the button.  Valid options are "bottom" (the default)
+#' or "top"
 #'
 #' @importFrom shiny actionButton NS icon
 #'
 #' @return admin button UI
 #'
-#' @noRd
+#' @export
 #'
-admin_button_ui <- function(id) {
-  ns <- shiny::NS(id)
+admin_button_ui <- function(align = "right", vertical_align = "bottom") {
+  ns <- shiny::NS("polished")
 
   shiny::actionButton(
     ns("go_to_admin_panel"),
     "Admin Panel",
     icon = shiny::icon("cog"),
     class = "btn-primary btn-lg",
-    style = "position: fixed; bottom: 15px; right: 15px; color: #FFFFFF; z-index: 9999;"
+    style = paste0("position: fixed; ", vertical_align, ": 15px; ", align, ": 15px; color: #FFFFFF; z-index: 9999;")
   )
 }
 
