@@ -1,17 +1,17 @@
-#' Secure a static html page
+#' Secure a static HTML page
 #'
-#' \code{secure_static()} can be used to secure any html
-#' page using 'polished'.  It is often used to add 'polished' to ".Rmd" htmloutput
+#' \code{secure_static()} can be used to secure any HTML
+#' page using \code{polished}.  It is often used to add \code{polished} to \code{.Rmd} htmloutput
 #' and flexdashboards.
 #'
-#' @param html_file_path the path the to html file.  See the details for more info.
+#' @param html_file_path the path the to HTML file.  See the details for more info.
 #' @param global_sessions_config_args arguments to be passed to \code{\link{global_sessions_config}}.
-#' @param sign_out_button action button or link with inputId "sign_out". Set to NULL to not include a sign out button.
+#' @param sign_out_button action button or link with \code{inputId = "sign_out"}. Set to \code{NULL} to not include a sign out button.
 #'
 #' @md
 #'
-#' @details To secure a static html page, place the html page in a folder named "www"
-#' and call \code{secure_static()} from a file named "app.R".  The file structure should
+#' @details To secure a static HTML page, place the HTML page in a folder named "www"
+#' and call \code{secure_static()} from a file named \code{app.R}.  The file structure should
 #' look like:
 #'
 #' - app.R
@@ -68,7 +68,7 @@ secure_static <- function(
     )
   )
 
-  ui <- secure_ui(
+  ui_out <- secure_ui(
     ui,
     custom_admin_button_ui = shiny::actionButton(
       "polished-go_to_admin_panel",
@@ -93,7 +93,7 @@ secure_static <- function(
   })
 
 
-  shiny::shinyApp(ui, server, onStart = function() {
+  shiny::shinyApp(ui_out, server, onStart = function() {
     library(polished)
 
     # configure the global sessions when the app initially starts up.
